age

package
v0.22.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DecryptSecretsFile

func DecryptSecretsFile(rootDir string) error

DecryptSecretsFile decrypts secrets.encrypted.yaml and saves to secrets.yaml

func DecryptYAMLFile

func DecryptYAMLFile(rootDir, encryptedFile, plainFile string) error

DecryptYAMLFile decrypts an encrypted YAML file's values and saves to plain file

func EncryptSecretsFile

func EncryptSecretsFile(rootDir string) error

EncryptSecretsFile encrypts secrets.yaml values and saves to secrets.encrypted.yaml Uses incremental encryption: only encrypts values that have changed

func EncryptYAMLFile

func EncryptYAMLFile(rootDir, plainFile, encryptedFile string) error

EncryptYAMLFile encrypts a YAML file's values (keeping keys unencrypted) and saves to encrypted file Uses incremental encryption: only encrypts values that have changed

func GenerateKey

func GenerateKey(rootDir string) (*age.X25519Identity, bool, error)

GenerateKey generates a new age identity and saves it to talm.key file in age keygen format Returns true if a new key was created (not loaded from existing file)

func GetPublicKey

func GetPublicKey(identity *age.X25519Identity) string

GetPublicKey returns the public key from an identity

func GetPublicKeyFromFile

func GetPublicKeyFromFile(rootDir string) (string, error)

GetPublicKeyFromFile extracts the public key from talm.key file

func LoadKey

func LoadKey(rootDir string) (*age.X25519Identity, error)

LoadKey loads age identity from talm.key file Supports both age keygen format (with comments) and plain format

func RotateKeys

func RotateKeys(rootDir string) error

RotateKeys rotates encryption keys in secrets.encrypted.yaml

Types

This section is empty.

Jump to