Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AvailablePresets ¶
AvailablePresets returns a list of available preset chart names. The "generic" preset is always first if it exists.
func PresetFiles ¶
PresetFiles returns a map of file paths to their contents. For Chart.yaml files, name and version are replaced with %s placeholders.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.