charts

package
v0.17.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 18, 2025 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AvailablePresets

func AvailablePresets() ([]string, error)

AvailablePresets returns a list of available preset chart names. The "generic" preset is always first if it exists.

func PresetFiles

func PresetFiles() (map[string]string, error)

PresetFiles returns a map of file paths to their contents. For Chart.yaml files, name and version are replaced with %s placeholders.

Types

This section is empty.

Jump to